@@ -1,7 +1,7 @@
 from webthing import (SingleThing, Property, Thing, Value, WebThingServer)
 import logging
-import tornado.ioloop
 import RPi.GPIO as GPIO
+import tornado.ioloop
 
 
 class LightSensor(Thing):
@@ -22,6 +22,8 @@ class LightSensor(Thing):
         GPIO.setmode(GPIO.BCM)
         GPIO.setup(self.gpio_number, GPIO.IN)
 
+        self.timer = tornado.ioloop.PeriodicCallback(self.__measure, 10000)
+
         self.bright = Value(False)
         self.add_property(
             Property(self,
@@ -34,22 +36,16 @@ class LightSensor(Thing):
                          'description': 'Whether the lamp is bright',
                          'readOnly': True,
                      }))
-
-        logging.debug('starting the sensor update looping task')
-        self.timer = tornado.ioloop.PeriodicCallback(
-            self.measure,
-            60000
-        )
-        self.measure()
         self.timer.start()
 
-    def measure(self):
+    def __measure(self, channel):
         if GPIO.input(self.gpio_number):
             self.bright.notify_of_external_update(True)
         else:
             self.bright.notify_of_external_update(True)
+        logging.info("bright=" + str(self.bright.get()))
 
-    def cancel_update_level_task(self):
+    def cancel_measure_task(self):
         self.timer.stop()
 
 
@@ -60,9 +56,8 @@ def run_server(port, gpio_number, description):
         logging.info('starting the server')
         server.start()
     except KeyboardInterrupt:
-        logging.debug('canceling the sensor update looping task')
-        light_sensor.cancel_update_level_task()
         logging.info('stopping the server')
+        light_sensor.cancel_measure_task()
         server.stop()
         logging.info('done')
 
